@@ -5,7 +5,7 @@
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
 ;; URL: https://github.com/protesilaos/consult-denote
-;; Version: 0.2.3
+;; Version: 0.2.4
 ;; Package-Requires: ((emacs "28.1") (denote "3.0.3") (consult "1.7"))
 
 ;; This file is NOT part of GNU Emacs.
@@ -242,9 +242,7 @@ FILE has the same meaning as in `denote-org-extras-outline-prompt'."
      :items ,#'denote-directory-subdirectories)
   "Source for `consult-buffer' to list Denote subdirectories.")
 
-;; This must not be nil, as `:items' is mandatory (`plist-member'),
-;; even if its value is nil.
-(defvar consult-denote-silo-source '(:items nil)
+(defvar consult-denote-silo-source nil
   "Source for `consult-buffer' to list Denote silos.")
 
 (with-eval-after-load 'denote-silo-extras
@@ -283,29 +281,5 @@ FILE has the same meaning as in `denote-org-extras-outline-prompt'."
     (advice-remove #'denote-org-extras-outline-prompt #'consult-denote-outline-prompt)
     (advice-remove #'denote-silo-extras-directory-prompt #'consult-denote-silo-directory-prompt)))
 
-;;;; Alternatives to Denote functions
-
-(defun consult-denote--subdirectory-p (directory)
-  "Return non-nil if DIRECTORY is a subdirectory of variable `denote-directory'."
-  (member directory (denote-directory-subdirectories)))
-
-(defun consult-denote--get-subdir-or-root ()
-  "Return current subdirectory of the variable `denote-directory'.
-If that is not available, return the value of variable
-`denote-directory'."
-  (if-let* ((current-dir (expand-file-name default-directory))
-            ((consult-denote--subdirectory-p current-dir)))
-      current-dir
-    (denote-directory)))
-
-(defun consult-denote--get-file-with-find (&optional directory)
-  "Use Consult to find a file in the variable `denote-directory'.
-With optional DIRECTORY, search that directory instead."
-  (let ((dir (or directory (consult-denote--get-subdir-or-root))))
-    (pcase-let* ((`(,prompt ,paths ,dir) (consult--directory-prompt "Find" dir))
-                 (default-directory dir)
-                 (builder (consult--find-make-builder paths)))
-      (consult--find prompt builder nil))))
-
 (provide 'consult-denote)
 ;;; consult-denote.el ends here
